#==========================================
# Title:  time_def_
# Author: MaxF39
# Date:   23.06.2022
#==========================================

from setuptools import setup

setup(name='time_def',
      version='0.3',
      description='Print how long the function has been running',
      packages=['time_def'],
      author="Maxim Fedotov",
      author_email='maxf39@mail.ru',
      zip_safe=False)